@@ -3,4 +3,7 @@ By Al Sweigart al@inventwithpython.com
 
 A module to install the dependencies for the projects in The Big Book of Small Python Projects."""
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
+
+import webbrowser
+webbrowser.open('https://inventwithpython.com/bigbookpython/')
\ No newline at end of file
